# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.citation_metadata_api_dto import CitationMetadataApiDto

class TestCitationMetadataApiDto(unittest.TestCase):
    """CitationMetadataApiDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CitationMetadataApiDto:
        """Test CitationMetadataApiDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CitationMetadataApiDto`
        """
        model = CitationMetadataApiDto()
        if include_optional:
            return CitationMetadataApiDto(
                page_index = 56,
                paragraph_index = 56,
                text = '',
                url = '',
                description = '',
                analysis = perceptic_core_client.models.biotech_analysis_api_dto.BiotechAnalysisApiDto(
                    raw_analysis = '', 
                    compound_data_present = True, 
                    compounds = [
                        ''
                        ], 
                    development_stage = '', 
                    therapeutic_area = '', 
                    key_findings = [
                        ''
                        ], 
                    risks = [
                        ''
                        ], 
                    market_potential = '', 
                    confidence = 1.337, 
                    reasoning = '', 
                    bounding_boxes = [
                        perceptic_core_client.models.image_detection_box_api_dto.ImageDetectionBoxApiDto(
                            x_min = 56, 
                            y_min = 56, 
                            x_max = 56, 
                            y_max = 56, 
                            label = '', 
                            confidence = 1.337, )
                        ], 
                    page_index = 56, 
                    character_count = 56, )
            )
        else:
            return CitationMetadataApiDto(
        )
        """

    def testCitationMetadataApiDto(self):
        """Test CitationMetadataApiDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.json_node import JsonNode

class TestJsonNode(unittest.TestCase):
    """JsonNode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsonNode:
        """Test JsonNode
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsonNode`
        """
        model = JsonNode()
        if include_optional:
            return JsonNode(
                empty = True,
                value_node = True,
                container_node = True,
                missing_node = True,
                array = True,
                object = True,
                node_type = 'ARRAY',
                pojo = True,
                number = True,
                integral_number = True,
                floating_point_number = True,
                short = True,
                int = True,
                long = True,
                var_float = True,
                double = True,
                big_decimal = True,
                big_integer = True,
                textual = True,
                boolean = True,
                null = True,
                binary = True
            )
        else:
            return JsonNode(
        )
        """

    def testJsonNode(self):
        """Test JsonNode"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.list_schedule_executions_response import ListScheduleExecutionsResponse

class TestListScheduleExecutionsResponse(unittest.TestCase):
    """ListScheduleExecutionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListScheduleExecutionsResponse:
        """Test ListScheduleExecutionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListScheduleExecutionsResponse`
        """
        model = ListScheduleExecutionsResponse()
        if include_optional:
            return ListScheduleExecutionsResponse(
                executions = [
                    perceptic_core_client.models.schedule_execution_dto.ScheduleExecutionDto(
                        execution_rid = '', 
                        schedule_rid = '', 
                        task_rid = '', 
                        triggered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        reason = 'SCHEDULED', 
                        trigger_details = '', )
                    ],
                total_count = 56,
                next_offset = 56
            )
        else:
            return ListScheduleExecutionsResponse(
        )
        """

    def testListScheduleExecutionsResponse(self):
        """Test ListScheduleExecutionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBytes, StrictInt, StrictStr, field_validator
from typing import Any, Dict, Optional, Tuple, Union
from typing_extensions import Annotated
from perceptic_core_client.models.create_folder_request import CreateFolderRequest
from perceptic_core_client.models.create_folder_response import CreateFolderResponse
from perceptic_core_client.models.get_metadata_response import GetMetadataResponse
from perceptic_core_client.models.get_parent_response import GetParentResponse
from perceptic_core_client.models.get_signed_url_response import GetSignedUrlResponse
from perceptic_core_client.models.list_file_system_response import ListFileSystemResponse
from perceptic_core_client.models.paged_list_file_system_response import PagedListFileSystemResponse
from perceptic_core_client.models.upload_file_to_managed_file_system_response import UploadFileToManagedFileSystemResponse

from perceptic_core_client.api_client import ApiClient, RequestSerialized
from perceptic_core_client.api_response import ApiResponse
from perceptic_core_client.rest import RESTResponseType


class FileSystemContentsResourceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_folder(
        self,
        file_system_rid: StrictStr,
        create_folder_request: CreateFolderRequest,
        parent: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CreateFolderResponse:
        """Create Folder


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param create_folder_request: (required)
        :type create_folder_request: CreateFolderRequest
        :param parent:
        :type parent: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_folder_serialize(
            file_system_rid=file_system_rid,
            create_folder_request=create_folder_request,
            parent=parent,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateFolderResponse",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_folder_with_http_info(
        self,
        file_system_rid: StrictStr,
        create_folder_request: CreateFolderRequest,
        parent: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CreateFolderResponse]:
        """Create Folder


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param create_folder_request: (required)
        :type create_folder_request: CreateFolderRequest
        :param parent:
        :type parent: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_folder_serialize(
            file_system_rid=file_system_rid,
            create_folder_request=create_folder_request,
            parent=parent,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateFolderResponse",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_folder_without_preload_content(
        self,
        file_system_rid: StrictStr,
        create_folder_request: CreateFolderRequest,
        parent: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Folder


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param create_folder_request: (required)
        :type create_folder_request: CreateFolderRequest
        :param parent:
        :type parent: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_folder_serialize(
            file_system_rid=file_system_rid,
            create_folder_request=create_folder_request,
            parent=parent,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateFolderResponse",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_folder_serialize(
        self,
        file_system_rid,
        create_folder_request,
        parent,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_system_rid is not None:
            _path_params['fileSystemRid'] = file_system_rid
        # process the query parameters
        if parent is not None:
            
            _query_params.append(('parent', parent))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_folder_request is not None:
            _body_params = create_folder_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/file-systems/{fileSystemRid}/contents/folders',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def download_file(
        self,
        file_system_rid: StrictStr,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> bytearray:
        """Download


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._download_file_serialize(
            file_system_rid=file_system_rid,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def download_file_with_http_info(
        self,
        file_system_rid: StrictStr,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[bytearray]:
        """Download


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._download_file_serialize(
            file_system_rid=file_system_rid,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def download_file_without_preload_content(
        self,
        file_system_rid: StrictStr,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Download


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._download_file_serialize(
            file_system_rid=file_system_rid,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _download_file_serialize(
        self,
        file_system_rid,
        file,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_system_rid is not None:
            _path_params['fileSystemRid'] = file_system_rid
        # process the query parameters
        if file is not None:
            
            _query_params.append(('file', file))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/octet-stream'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/file-systems/{fileSystemRid}/contents/download',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_metadata(
        self,
        file_system_rid: StrictStr,
        id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetMetadataResponse:
        """Get Metadata


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param id:
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_metadata_serialize(
            file_system_rid=file_system_rid,
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetMetadataResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_metadata_with_http_info(
        self,
        file_system_rid: StrictStr,
        id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetMetadataResponse]:
        """Get Metadata


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param id:
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_metadata_serialize(
            file_system_rid=file_system_rid,
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetMetadataResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_metadata_without_preload_content(
        self,
        file_system_rid: StrictStr,
        id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Metadata


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param id:
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_metadata_serialize(
            file_system_rid=file_system_rid,
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetMetadataResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_metadata_serialize(
        self,
        file_system_rid,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_system_rid is not None:
            _path_params['fileSystemRid'] = file_system_rid
        # process the query parameters
        if id is not None:
            
            _query_params.append(('id', id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/file-systems/{fileSystemRid}/contents/metadata',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_parent_resource(
        self,
        file_system_rid: StrictStr,
        id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetParentResponse:
        """Get Parent


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param id:
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_parent_resource_serialize(
            file_system_rid=file_system_rid,
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetParentResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_parent_resource_with_http_info(
        self,
        file_system_rid: StrictStr,
        id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetParentResponse]:
        """Get Parent


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param id:
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_parent_resource_serialize(
            file_system_rid=file_system_rid,
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetParentResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_parent_resource_without_preload_content(
        self,
        file_system_rid: StrictStr,
        id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Parent


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param id:
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_parent_resource_serialize(
            file_system_rid=file_system_rid,
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetParentResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_parent_resource_serialize(
        self,
        file_system_rid,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_system_rid is not None:
            _path_params['fileSystemRid'] = file_system_rid
        # process the query parameters
        if id is not None:
            
            _query_params.append(('id', id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/file-systems/{fileSystemRid}/contents/parent',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_signed_url(
        self,
        file_system_rid: StrictStr,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetSignedUrlResponse:
        """Signed Url


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_signed_url_serialize(
            file_system_rid=file_system_rid,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSignedUrlResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_signed_url_with_http_info(
        self,
        file_system_rid: StrictStr,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetSignedUrlResponse]:
        """Signed Url


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_signed_url_serialize(
            file_system_rid=file_system_rid,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSignedUrlResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_signed_url_without_preload_content(
        self,
        file_system_rid: StrictStr,
        file: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Signed Url


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file:
        :type file: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_signed_url_serialize(
            file_system_rid=file_system_rid,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetSignedUrlResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_signed_url_serialize(
        self,
        file_system_rid,
        file,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_system_rid is not None:
            _path_params['fileSystemRid'] = file_system_rid
        # process the query parameters
        if file is not None:
            
            _query_params.append(('file', file))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/file-systems/{fileSystemRid}/contents/signed-url',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_files_flattened(
        self,
        file_system_rid: StrictStr,
        folder: Optional[StrictStr] = None,
        page_size: Optional[StrictInt] = None,
        resume_token: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PagedListFileSystemResponse:
        """List Files Flattened


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param folder:
        :type folder: str
        :param page_size:
        :type page_size: int
        :param resume_token:
        :type resume_token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_files_flattened_serialize(
            file_system_rid=file_system_rid,
            folder=folder,
            page_size=page_size,
            resume_token=resume_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PagedListFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_files_flattened_with_http_info(
        self,
        file_system_rid: StrictStr,
        folder: Optional[StrictStr] = None,
        page_size: Optional[StrictInt] = None,
        resume_token: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PagedListFileSystemResponse]:
        """List Files Flattened


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param folder:
        :type folder: str
        :param page_size:
        :type page_size: int
        :param resume_token:
        :type resume_token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_files_flattened_serialize(
            file_system_rid=file_system_rid,
            folder=folder,
            page_size=page_size,
            resume_token=resume_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PagedListFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_files_flattened_without_preload_content(
        self,
        file_system_rid: StrictStr,
        folder: Optional[StrictStr] = None,
        page_size: Optional[StrictInt] = None,
        resume_token: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Files Flattened


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param folder:
        :type folder: str
        :param page_size:
        :type page_size: int
        :param resume_token:
        :type resume_token: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_files_flattened_serialize(
            file_system_rid=file_system_rid,
            folder=folder,
            page_size=page_size,
            resume_token=resume_token,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PagedListFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_files_flattened_serialize(
        self,
        file_system_rid,
        folder,
        page_size,
        resume_token,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_system_rid is not None:
            _path_params['fileSystemRid'] = file_system_rid
        # process the query parameters
        if folder is not None:
            
            _query_params.append(('folder', folder))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if resume_token is not None:
            
            _query_params.append(('resumeToken', resume_token))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/file-systems/{fileSystemRid}/contents/files',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_folder_contents(
        self,
        file_system_rid: StrictStr,
        folder: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ListFileSystemResponse:
        """List


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param folder:
        :type folder: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_folder_contents_serialize(
            file_system_rid=file_system_rid,
            folder=folder,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_folder_contents_with_http_info(
        self,
        file_system_rid: StrictStr,
        folder: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ListFileSystemResponse]:
        """List


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param folder:
        :type folder: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_folder_contents_serialize(
            file_system_rid=file_system_rid,
            folder=folder,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_folder_contents_without_preload_content(
        self,
        file_system_rid: StrictStr,
        folder: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param folder:
        :type folder: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_folder_contents_serialize(
            file_system_rid=file_system_rid,
            folder=folder,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_folder_contents_serialize(
        self,
        file_system_rid,
        folder,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_system_rid is not None:
            _path_params['fileSystemRid'] = file_system_rid
        # process the query parameters
        if folder is not None:
            
            _query_params.append(('folder', folder))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/file-systems/{fileSystemRid}/contents/list',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def upload_file(
        self,
        file_system_rid: StrictStr,
        file: Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]],
        filename: Annotated[str, Field(strict=True)],
        overwrite: Optional[Dict[str, Any]] = None,
        parent: Optional[Any] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UploadFileToManagedFileSystemResponse:
        """Upload File


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file: (required)
        :type file: bytearray
        :param filename: (required)
        :type filename: str
        :param overwrite:
        :type overwrite: object
        :param parent:
        :type parent: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_file_serialize(
            file_system_rid=file_system_rid,
            file=file,
            filename=filename,
            overwrite=overwrite,
            parent=parent,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UploadFileToManagedFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def upload_file_with_http_info(
        self,
        file_system_rid: StrictStr,
        file: Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]],
        filename: Annotated[str, Field(strict=True)],
        overwrite: Optional[Dict[str, Any]] = None,
        parent: Optional[Any] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UploadFileToManagedFileSystemResponse]:
        """Upload File


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file: (required)
        :type file: bytearray
        :param filename: (required)
        :type filename: str
        :param overwrite:
        :type overwrite: object
        :param parent:
        :type parent: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_file_serialize(
            file_system_rid=file_system_rid,
            file=file,
            filename=filename,
            overwrite=overwrite,
            parent=parent,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UploadFileToManagedFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def upload_file_without_preload_content(
        self,
        file_system_rid: StrictStr,
        file: Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]],
        filename: Annotated[str, Field(strict=True)],
        overwrite: Optional[Dict[str, Any]] = None,
        parent: Optional[Any] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload File


        :param file_system_rid: (required)
        :type file_system_rid: str
        :param file: (required)
        :type file: bytearray
        :param filename: (required)
        :type filename: str
        :param overwrite:
        :type overwrite: object
        :param parent:
        :type parent: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_file_serialize(
            file_system_rid=file_system_rid,
            file=file,
            filename=filename,
            overwrite=overwrite,
            parent=parent,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UploadFileToManagedFileSystemResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _upload_file_serialize(
        self,
        file_system_rid,
        file,
        filename,
        overwrite,
        parent,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_system_rid is not None:
            _path_params['fileSystemRid'] = file_system_rid
        # process the query parameters
        if overwrite is not None:
            
            _query_params.append(('overwrite', overwrite))
            
        # process the header parameters
        # process the form parameters
        if file is not None:
            _files['file'] = file
        if filename is not None:
            _form_params.append(('filename', filename))
        if parent is not None:
            _form_params.append(('parent', parent))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/file-systems/{fileSystemRid}/contents/upload',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "CitationsResourceApi",
    "ConnectionResourceApi",
    "FileSystemContentsResourceApi",
    "FileSystemResourceApi",
    "IndexerResourceApi",
    "IndexingScheduleResourceApi",
    "IndexingTaskResourceApi",
    "TagResourceApi",
    "UriResourceApi",
    "UserResourceApi",
    "WorkerResourceApi",
    "WorkflowResourceV3Api",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ActionType",
    "AddTagToFileRequest",
    "AzureBlobConnectionSettingsApiDto",
    "AzureBlobFileSystemRootMetadataApiDto",
    "BiotechAnalysisApiDto",
    "BiotechAnalysisImageAnnotatedCitationApiDto",
    "BulkGetCitationsRequest",
    "BulkGetCitationsResponse",
    "CitationApiDto",
    "CitationMetadataApiDto",
    "ConnectionApiDto",
    "ConnectionSettingsApiDto",
    "CreateConnectionRequest",
    "CreateConnectionResponse",
    "CreateFileSystemResponse",
    "CreateFolderRequest",
    "CreateFolderResponse",
    "CreateFolderResponseV2",
    "CreateIndexingScheduleRequest",
    "CreateIndexingScheduleResponse",
    "CreateIndexingTaskRequest",
    "CreateIndexingTaskResponse",
    "CreateManagedFileSystemRequest",
    "CreateRemoteFileSystemRequest",
    "CreateTagRequest",
    "CreateTagResponse",
    "CronTrigger",
    "ExecutionTriggerReason",
    "FileSystemApiDto",
    "FileSystemRootMetadataApiDto",
    "GetCitationOutputUriResponse",
    "GetConnectionResponse",
    "GetIndexerResponse",
    "GetIndexingScheduleResponse",
    "GetIndexingTaskResponse",
    "GetMetadataResponse",
    "GetParentResponse",
    "GetParentUriResponse",
    "GetRunEventRatingResponse",
    "GetSignedUrlResponse",
    "GetWorkerEventsResponse",
    "GetWorkerEventsV2Response",
    "GetWorkerMetadataResponse",
    "GetWorkerRunResponse",
    "GetWorkerStatusResponse",
    "GetWorkersResponse",
    "GetWorkflowEventsV3Response",
    "HighlightedTextCitationMetadataApiDto",
    "ImageDetectionBoxApiDto",
    "IndexerDto",
    "IndexingActionDto",
    "IndexingActionStatus",
    "IndexingScheduleDto",
    "IndexingTaskDto",
    "IndexingTaskStatus",
    "InfoEvent",
    "InfoEvent1",
    "IngestEventRequest",
    "IngestEventResponse",
    "InterruptWorkflowRunRequest",
    "IntervalTrigger",
    "InvokeWorkflowCheckpointRequest",
    "InvokeWorkflowCheckpointResponse",
    "JsonNode",
    "JsonNodeType",
    "ListAllFileSystemsResponse",
    "ListFileSystemResponse",
    "ListIndexersResponse",
    "ListIndexingActionsResponse",
    "ListIndexingSchedulesResponse",
    "ListScheduleExecutionsResponse",
    "ListTagsResponse",
    "ListUsersResponse",
    "ManagedFileSystemApiDto",
    "MeResponse",
    "ModelSchema",
    "OnUploadTrigger",
    "PagedListFileSystemResponse",
    "PersistenceMode",
    "PostRatingRequest",
    "PostRunEventRatingResponse",
    "PostWorkerRunRequest",
    "PostWorkerRunResponse",
    "PostWorkflowRunRequest",
    "PostWorkflowRunResponse",
    "ProgressEvent",
    "ProgressEvent1",
    "RatingDtoWorkerRunEventRatingSecondaryId",
    "RemoteFileSystemApiDto",
    "RemoveTagFromFileRequest",
    "RequestForInputEvent",
    "ResourceEntryDto",
    "ResourceIdentifier",
    "ResourceMetadataDto",
    "ResourceTypeDto",
    "RunStatusDto",
    "S3ConnectionSettingsApiDto",
    "S3FileSystemRootMetadataApiDto",
    "ScheduleExecutionDto",
    "ScheduleTrigger",
    "SchemaLocation",
    "StartExecutionResponse",
    "TagInfo",
    "UpdateIndexingScheduleRequest",
    "UpdateIndexingScheduleResponse",
    "UpdateTagRequest",
    "UpdateTagResponse",
    "UploadFileToManagedFileSystemResponse",
    "UploadResourceResponseV2",
    "UserInfoResponse",
    "UserInputEvent",
    "UserRequestForInputEvent",
    "WebPageCitationMetadataApiDto",
    "WorkerEvent",
    "WorkerEventV2",
    "WorkerMetadataDto",
    "WorkerRunEventRatingSecondaryId",
    "WorkerV2NextPageToken",
    "WorkflowStatusResponse",
]

# import apis into sdk package
from perceptic_core_client.api.citations_resource_api import CitationsResourceApi as CitationsResourceApi
from perceptic_core_client.api.connection_resource_api import ConnectionResourceApi as ConnectionResourceApi
from perceptic_core_client.api.file_system_contents_resource_api import FileSystemContentsResourceApi as FileSystemContentsResourceApi
from perceptic_core_client.api.file_system_resource_api import FileSystemResourceApi as FileSystemResourceApi
from perceptic_core_client.api.indexer_resource_api import IndexerResourceApi as IndexerResourceApi
from perceptic_core_client.api.indexing_schedule_resource_api import IndexingScheduleResourceApi as IndexingScheduleResourceApi
from perceptic_core_client.api.indexing_task_resource_api import IndexingTaskResourceApi as IndexingTaskResourceApi
from perceptic_core_client.api.tag_resource_api import TagResourceApi as TagResourceApi
from perceptic_core_client.api.uri_resource_api import UriResourceApi as UriResourceApi
from perceptic_core_client.api.user_resource_api import UserResourceApi as UserResourceApi
from perceptic_core_client.api.worker_resource_api import WorkerResourceApi as WorkerResourceApi
from perceptic_core_client.api.workflow_resource_v3_api import WorkflowResourceV3Api as WorkflowResourceV3Api

# import ApiClient
from perceptic_core_client.api_response import ApiResponse as ApiResponse
from perceptic_core_client.api_client import ApiClient as ApiClient
from perceptic_core_client.configuration import Configuration as Configuration
from perceptic_core_client.exceptions import OpenApiException as OpenApiException
from perceptic_core_client.exceptions import ApiTypeError as ApiTypeError
from perceptic_core_client.exceptions import ApiValueError as ApiValueError
from perceptic_core_client.exceptions import ApiKeyError as ApiKeyError
from perceptic_core_client.exceptions import ApiAttributeError as ApiAttributeError
from perceptic_core_client.exceptions import ApiException as ApiException

# import models into sdk package
from perceptic_core_client.models.action_type import ActionType as ActionType
from perceptic_core_client.models.add_tag_to_file_request import AddTagToFileRequest as AddTagToFileRequest
from perceptic_core_client.models.azure_blob_connection_settings_api_dto import AzureBlobConnectionSettingsApiDto as AzureBlobConnectionSettingsApiDto
from perceptic_core_client.models.azure_blob_file_system_root_metadata_api_dto import AzureBlobFileSystemRootMetadataApiDto as AzureBlobFileSystemRootMetadataApiDto
from perceptic_core_client.models.biotech_analysis_api_dto import BiotechAnalysisApiDto as BiotechAnalysisApiDto
from perceptic_core_client.models.biotech_analysis_image_annotated_citation_api_dto import BiotechAnalysisImageAnnotatedCitationApiDto as BiotechAnalysisImageAnnotatedCitationApiDto
from perceptic_core_client.models.bulk_get_citations_request import BulkGetCitationsRequest as BulkGetCitationsRequest
from perceptic_core_client.models.bulk_get_citations_response import BulkGetCitationsResponse as BulkGetCitationsResponse
from perceptic_core_client.models.citation_api_dto import CitationApiDto as CitationApiDto
from perceptic_core_client.models.citation_metadata_api_dto import CitationMetadataApiDto as CitationMetadataApiDto
from perceptic_core_client.models.connection_api_dto import ConnectionApiDto as ConnectionApiDto
from perceptic_core_client.models.connection_settings_api_dto import ConnectionSettingsApiDto as ConnectionSettingsApiDto
from perceptic_core_client.models.create_connection_request import CreateConnectionRequest as CreateConnectionRequest
from perceptic_core_client.models.create_connection_response import CreateConnectionResponse as CreateConnectionResponse
from perceptic_core_client.models.create_file_system_response import CreateFileSystemResponse as CreateFileSystemResponse
from perceptic_core_client.models.create_folder_request import CreateFolderRequest as CreateFolderRequest
from perceptic_core_client.models.create_folder_response import CreateFolderResponse as CreateFolderResponse
from perceptic_core_client.models.create_folder_response_v2 import CreateFolderResponseV2 as CreateFolderResponseV2
from perceptic_core_client.models.create_indexing_schedule_request import CreateIndexingScheduleRequest as CreateIndexingScheduleRequest
from perceptic_core_client.models.create_indexing_schedule_response import CreateIndexingScheduleResponse as CreateIndexingScheduleResponse
from perceptic_core_client.models.create_indexing_task_request import CreateIndexingTaskRequest as CreateIndexingTaskRequest
from perceptic_core_client.models.create_indexing_task_response import CreateIndexingTaskResponse as CreateIndexingTaskResponse
from perceptic_core_client.models.create_managed_file_system_request import CreateManagedFileSystemRequest as CreateManagedFileSystemRequest
from perceptic_core_client.models.create_remote_file_system_request import CreateRemoteFileSystemRequest as CreateRemoteFileSystemRequest
from perceptic_core_client.models.create_tag_request import CreateTagRequest as CreateTagRequest
from perceptic_core_client.models.create_tag_response import CreateTagResponse as CreateTagResponse
from perceptic_core_client.models.cron_trigger import CronTrigger as CronTrigger
from perceptic_core_client.models.execution_trigger_reason import ExecutionTriggerReason as ExecutionTriggerReason
from perceptic_core_client.models.file_system_api_dto import FileSystemApiDto as FileSystemApiDto
from perceptic_core_client.models.file_system_root_metadata_api_dto import FileSystemRootMetadataApiDto as FileSystemRootMetadataApiDto
from perceptic_core_client.models.get_citation_output_uri_response import GetCitationOutputUriResponse as GetCitationOutputUriResponse
from perceptic_core_client.models.get_connection_response import GetConnectionResponse as GetConnectionResponse
from perceptic_core_client.models.get_indexer_response import GetIndexerResponse as GetIndexerResponse
from perceptic_core_client.models.get_indexing_schedule_response import GetIndexingScheduleResponse as GetIndexingScheduleResponse
from perceptic_core_client.models.get_indexing_task_response import GetIndexingTaskResponse as GetIndexingTaskResponse
from perceptic_core_client.models.get_metadata_response import GetMetadataResponse as GetMetadataResponse
from perceptic_core_client.models.get_parent_response import GetParentResponse as GetParentResponse
from perceptic_core_client.models.get_parent_uri_response import GetParentUriResponse as GetParentUriResponse
from perceptic_core_client.models.get_run_event_rating_response import GetRunEventRatingResponse as GetRunEventRatingResponse
from perceptic_core_client.models.get_signed_url_response import GetSignedUrlResponse as GetSignedUrlResponse
from perceptic_core_client.models.get_worker_events_response import GetWorkerEventsResponse as GetWorkerEventsResponse
from perceptic_core_client.models.get_worker_events_v2_response import GetWorkerEventsV2Response as GetWorkerEventsV2Response
from perceptic_core_client.models.get_worker_metadata_response import GetWorkerMetadataResponse as GetWorkerMetadataResponse
from perceptic_core_client.models.get_worker_run_response import GetWorkerRunResponse as GetWorkerRunResponse
from perceptic_core_client.models.get_worker_status_response import GetWorkerStatusResponse as GetWorkerStatusResponse
from perceptic_core_client.models.get_workers_response import GetWorkersResponse as GetWorkersResponse
from perceptic_core_client.models.get_workflow_events_v3_response import GetWorkflowEventsV3Response as GetWorkflowEventsV3Response
from perceptic_core_client.models.highlighted_text_citation_metadata_api_dto import HighlightedTextCitationMetadataApiDto as HighlightedTextCitationMetadataApiDto
from perceptic_core_client.models.image_detection_box_api_dto import ImageDetectionBoxApiDto as ImageDetectionBoxApiDto
from perceptic_core_client.models.indexer_dto import IndexerDto as IndexerDto
from perceptic_core_client.models.indexing_action_dto import IndexingActionDto as IndexingActionDto
from perceptic_core_client.models.indexing_action_status import IndexingActionStatus as IndexingActionStatus
from perceptic_core_client.models.indexing_schedule_dto import IndexingScheduleDto as IndexingScheduleDto
from perceptic_core_client.models.indexing_task_dto import IndexingTaskDto as IndexingTaskDto
from perceptic_core_client.models.indexing_task_status import IndexingTaskStatus as IndexingTaskStatus
from perceptic_core_client.models.info_event import InfoEvent as InfoEvent
from perceptic_core_client.models.info_event1 import InfoEvent1 as InfoEvent1
from perceptic_core_client.models.ingest_event_request import IngestEventRequest as IngestEventRequest
from perceptic_core_client.models.ingest_event_response import IngestEventResponse as IngestEventResponse
from perceptic_core_client.models.interrupt_workflow_run_request import InterruptWorkflowRunRequest as InterruptWorkflowRunRequest
from perceptic_core_client.models.interval_trigger import IntervalTrigger as IntervalTrigger
from perceptic_core_client.models.invoke_workflow_checkpoint_request import InvokeWorkflowCheckpointRequest as InvokeWorkflowCheckpointRequest
from perceptic_core_client.models.invoke_workflow_checkpoint_response import InvokeWorkflowCheckpointResponse as InvokeWorkflowCheckpointResponse
from perceptic_core_client.models.json_node import JsonNode as JsonNode
from perceptic_core_client.models.json_node_type import JsonNodeType as JsonNodeType
from perceptic_core_client.models.list_all_file_systems_response import ListAllFileSystemsResponse as ListAllFileSystemsResponse
from perceptic_core_client.models.list_file_system_response import ListFileSystemResponse as ListFileSystemResponse
from perceptic_core_client.models.list_indexers_response import ListIndexersResponse as ListIndexersResponse
from perceptic_core_client.models.list_indexing_actions_response import ListIndexingActionsResponse as ListIndexingActionsResponse
from perceptic_core_client.models.list_indexing_schedules_response import ListIndexingSchedulesResponse as ListIndexingSchedulesResponse
from perceptic_core_client.models.list_schedule_executions_response import ListScheduleExecutionsResponse as ListScheduleExecutionsResponse
from perceptic_core_client.models.list_tags_response import ListTagsResponse as ListTagsResponse
from perceptic_core_client.models.list_users_response import ListUsersResponse as ListUsersResponse
from perceptic_core_client.models.managed_file_system_api_dto import ManagedFileSystemApiDto as ManagedFileSystemApiDto
from perceptic_core_client.models.me_response import MeResponse as MeResponse
from perceptic_core_client.models.model_schema import ModelSchema as ModelSchema
from perceptic_core_client.models.on_upload_trigger import OnUploadTrigger as OnUploadTrigger
from perceptic_core_client.models.paged_list_file_system_response import PagedListFileSystemResponse as PagedListFileSystemResponse
from perceptic_core_client.models.persistence_mode import PersistenceMode as PersistenceMode
from perceptic_core_client.models.post_rating_request import PostRatingRequest as PostRatingRequest
from perceptic_core_client.models.post_run_event_rating_response import PostRunEventRatingResponse as PostRunEventRatingResponse
from perceptic_core_client.models.post_worker_run_request import PostWorkerRunRequest as PostWorkerRunRequest
from perceptic_core_client.models.post_worker_run_response import PostWorkerRunResponse as PostWorkerRunResponse
from perceptic_core_client.models.post_workflow_run_request import PostWorkflowRunRequest as PostWorkflowRunRequest
from perceptic_core_client.models.post_workflow_run_response import PostWorkflowRunResponse as PostWorkflowRunResponse
from perceptic_core_client.models.progress_event import ProgressEvent as ProgressEvent
from perceptic_core_client.models.progress_event1 import ProgressEvent1 as ProgressEvent1
from perceptic_core_client.models.rating_dto_worker_run_event_rating_secondary_id import RatingDtoWorkerRunEventRatingSecondaryId as RatingDtoWorkerRunEventRatingSecondaryId
from perceptic_core_client.models.remote_file_system_api_dto import RemoteFileSystemApiDto as RemoteFileSystemApiDto
from perceptic_core_client.models.remove_tag_from_file_request import RemoveTagFromFileRequest as RemoveTagFromFileRequest
from perceptic_core_client.models.request_for_input_event import RequestForInputEvent as RequestForInputEvent
from perceptic_core_client.models.resource_entry_dto import ResourceEntryDto as ResourceEntryDto
from perceptic_core_client.models.resource_identifier import ResourceIdentifier as ResourceIdentifier
from perceptic_core_client.models.resource_metadata_dto import ResourceMetadataDto as ResourceMetadataDto
from perceptic_core_client.models.resource_type_dto import ResourceTypeDto as ResourceTypeDto
from perceptic_core_client.models.run_status_dto import RunStatusDto as RunStatusDto
from perceptic_core_client.models.s3_connection_settings_api_dto import S3ConnectionSettingsApiDto as S3ConnectionSettingsApiDto
from perceptic_core_client.models.s3_file_system_root_metadata_api_dto import S3FileSystemRootMetadataApiDto as S3FileSystemRootMetadataApiDto
from perceptic_core_client.models.schedule_execution_dto import ScheduleExecutionDto as ScheduleExecutionDto
from perceptic_core_client.models.schedule_trigger import ScheduleTrigger as ScheduleTrigger
from perceptic_core_client.models.schema_location import SchemaLocation as SchemaLocation
from perceptic_core_client.models.start_execution_response import StartExecutionResponse as StartExecutionResponse
from perceptic_core_client.models.tag_info import TagInfo as TagInfo
from perceptic_core_client.models.update_indexing_schedule_request import UpdateIndexingScheduleRequest as UpdateIndexingScheduleRequest
from perceptic_core_client.models.update_indexing_schedule_response import UpdateIndexingScheduleResponse as UpdateIndexingScheduleResponse
from perceptic_core_client.models.update_tag_request import UpdateTagRequest as UpdateTagRequest
from perceptic_core_client.models.update_tag_response import UpdateTagResponse as UpdateTagResponse
from perceptic_core_client.models.upload_file_to_managed_file_system_response import UploadFileToManagedFileSystemResponse as UploadFileToManagedFileSystemResponse
from perceptic_core_client.models.upload_resource_response_v2 import UploadResourceResponseV2 as UploadResourceResponseV2
from perceptic_core_client.models.user_info_response import UserInfoResponse as UserInfoResponse
from perceptic_core_client.models.user_input_event import UserInputEvent as UserInputEvent
from perceptic_core_client.models.user_request_for_input_event import UserRequestForInputEvent as UserRequestForInputEvent
from perceptic_core_client.models.web_page_citation_metadata_api_dto import WebPageCitationMetadataApiDto as WebPageCitationMetadataApiDto
from perceptic_core_client.models.worker_event import WorkerEvent as WorkerEvent
from perceptic_core_client.models.worker_event_v2 import WorkerEventV2 as WorkerEventV2
from perceptic_core_client.models.worker_metadata_dto import WorkerMetadataDto as WorkerMetadataDto
from perceptic_core_client.models.worker_run_event_rating_secondary_id import WorkerRunEventRatingSecondaryId as WorkerRunEventRatingSecondaryId
from perceptic_core_client.models.worker_v2_next_page_token import WorkerV2NextPageToken as WorkerV2NextPageToken
from perceptic_core_client.models.workflow_status_response import WorkflowStatusResponse as WorkflowStatusResponse




# coding: utf-8

# flake8: noqa
"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from perceptic_core_client.models.action_type import ActionType
from perceptic_core_client.models.add_tag_to_file_request import AddTagToFileRequest
from perceptic_core_client.models.azure_blob_connection_settings_api_dto import AzureBlobConnectionSettingsApiDto
from perceptic_core_client.models.azure_blob_file_system_root_metadata_api_dto import AzureBlobFileSystemRootMetadataApiDto
from perceptic_core_client.models.biotech_analysis_api_dto import BiotechAnalysisApiDto
from perceptic_core_client.models.biotech_analysis_image_annotated_citation_api_dto import BiotechAnalysisImageAnnotatedCitationApiDto
from perceptic_core_client.models.bulk_get_citations_request import BulkGetCitationsRequest
from perceptic_core_client.models.bulk_get_citations_response import BulkGetCitationsResponse
from perceptic_core_client.models.citation_api_dto import CitationApiDto
from perceptic_core_client.models.citation_metadata_api_dto import CitationMetadataApiDto
from perceptic_core_client.models.connection_api_dto import ConnectionApiDto
from perceptic_core_client.models.connection_settings_api_dto import ConnectionSettingsApiDto
from perceptic_core_client.models.create_connection_request import CreateConnectionRequest
from perceptic_core_client.models.create_connection_response import CreateConnectionResponse
from perceptic_core_client.models.create_file_system_response import CreateFileSystemResponse
from perceptic_core_client.models.create_folder_request import CreateFolderRequest
from perceptic_core_client.models.create_folder_response import CreateFolderResponse
from perceptic_core_client.models.create_folder_response_v2 import CreateFolderResponseV2
from perceptic_core_client.models.create_indexing_schedule_request import CreateIndexingScheduleRequest
from perceptic_core_client.models.create_indexing_schedule_response import CreateIndexingScheduleResponse
from perceptic_core_client.models.create_indexing_task_request import CreateIndexingTaskRequest
from perceptic_core_client.models.create_indexing_task_response import CreateIndexingTaskResponse
from perceptic_core_client.models.create_managed_file_system_request import CreateManagedFileSystemRequest
from perceptic_core_client.models.create_remote_file_system_request import CreateRemoteFileSystemRequest
from perceptic_core_client.models.create_tag_request import CreateTagRequest
from perceptic_core_client.models.create_tag_response import CreateTagResponse
from perceptic_core_client.models.cron_trigger import CronTrigger
from perceptic_core_client.models.execution_trigger_reason import ExecutionTriggerReason
from perceptic_core_client.models.file_system_api_dto import FileSystemApiDto
from perceptic_core_client.models.file_system_root_metadata_api_dto import FileSystemRootMetadataApiDto
from perceptic_core_client.models.get_citation_output_uri_response import GetCitationOutputUriResponse
from perceptic_core_client.models.get_connection_response import GetConnectionResponse
from perceptic_core_client.models.get_indexer_response import GetIndexerResponse
from perceptic_core_client.models.get_indexing_schedule_response import GetIndexingScheduleResponse
from perceptic_core_client.models.get_indexing_task_response import GetIndexingTaskResponse
from perceptic_core_client.models.get_metadata_response import GetMetadataResponse
from perceptic_core_client.models.get_parent_response import GetParentResponse
from perceptic_core_client.models.get_parent_uri_response import GetParentUriResponse
from perceptic_core_client.models.get_run_event_rating_response import GetRunEventRatingResponse
from perceptic_core_client.models.get_signed_url_response import GetSignedUrlResponse
from perceptic_core_client.models.get_worker_events_response import GetWorkerEventsResponse
from perceptic_core_client.models.get_worker_events_v2_response import GetWorkerEventsV2Response
from perceptic_core_client.models.get_worker_metadata_response import GetWorkerMetadataResponse
from perceptic_core_client.models.get_worker_run_response import GetWorkerRunResponse
from perceptic_core_client.models.get_worker_status_response import GetWorkerStatusResponse
from perceptic_core_client.models.get_workers_response import GetWorkersResponse
from perceptic_core_client.models.get_workflow_events_v3_response import GetWorkflowEventsV3Response
from perceptic_core_client.models.highlighted_text_citation_metadata_api_dto import HighlightedTextCitationMetadataApiDto
from perceptic_core_client.models.image_detection_box_api_dto import ImageDetectionBoxApiDto
from perceptic_core_client.models.indexer_dto import IndexerDto
from perceptic_core_client.models.indexing_action_dto import IndexingActionDto
from perceptic_core_client.models.indexing_action_status import IndexingActionStatus
from perceptic_core_client.models.indexing_schedule_dto import IndexingScheduleDto
from perceptic_core_client.models.indexing_task_dto import IndexingTaskDto
from perceptic_core_client.models.indexing_task_status import IndexingTaskStatus
from perceptic_core_client.models.info_event import InfoEvent
from perceptic_core_client.models.info_event1 import InfoEvent1
from perceptic_core_client.models.ingest_event_request import IngestEventRequest
from perceptic_core_client.models.ingest_event_response import IngestEventResponse
from perceptic_core_client.models.interrupt_workflow_run_request import InterruptWorkflowRunRequest
from perceptic_core_client.models.interval_trigger import IntervalTrigger
from perceptic_core_client.models.invoke_workflow_checkpoint_request import InvokeWorkflowCheckpointRequest
from perceptic_core_client.models.invoke_workflow_checkpoint_response import InvokeWorkflowCheckpointResponse
from perceptic_core_client.models.json_node import JsonNode
from perceptic_core_client.models.json_node_type import JsonNodeType
from perceptic_core_client.models.list_all_file_systems_response import ListAllFileSystemsResponse
from perceptic_core_client.models.list_file_system_response import ListFileSystemResponse
from perceptic_core_client.models.list_indexers_response import ListIndexersResponse
from perceptic_core_client.models.list_indexing_actions_response import ListIndexingActionsResponse
from perceptic_core_client.models.list_indexing_schedules_response import ListIndexingSchedulesResponse
from perceptic_core_client.models.list_schedule_executions_response import ListScheduleExecutionsResponse
from perceptic_core_client.models.list_tags_response import ListTagsResponse
from perceptic_core_client.models.list_users_response import ListUsersResponse
from perceptic_core_client.models.managed_file_system_api_dto import ManagedFileSystemApiDto
from perceptic_core_client.models.me_response import MeResponse
from perceptic_core_client.models.model_schema import ModelSchema
from perceptic_core_client.models.on_upload_trigger import OnUploadTrigger
from perceptic_core_client.models.paged_list_file_system_response import PagedListFileSystemResponse
from perceptic_core_client.models.persistence_mode import PersistenceMode
from perceptic_core_client.models.post_rating_request import PostRatingRequest
from perceptic_core_client.models.post_run_event_rating_response import PostRunEventRatingResponse
from perceptic_core_client.models.post_worker_run_request import PostWorkerRunRequest
from perceptic_core_client.models.post_worker_run_response import PostWorkerRunResponse
from perceptic_core_client.models.post_workflow_run_request import PostWorkflowRunRequest
from perceptic_core_client.models.post_workflow_run_response import PostWorkflowRunResponse
from perceptic_core_client.models.progress_event import ProgressEvent
from perceptic_core_client.models.progress_event1 import ProgressEvent1
from perceptic_core_client.models.rating_dto_worker_run_event_rating_secondary_id import RatingDtoWorkerRunEventRatingSecondaryId
from perceptic_core_client.models.remote_file_system_api_dto import RemoteFileSystemApiDto
from perceptic_core_client.models.remove_tag_from_file_request import RemoveTagFromFileRequest
from perceptic_core_client.models.request_for_input_event import RequestForInputEvent
from perceptic_core_client.models.resource_entry_dto import ResourceEntryDto
from perceptic_core_client.models.resource_identifier import ResourceIdentifier
from perceptic_core_client.models.resource_metadata_dto import ResourceMetadataDto
from perceptic_core_client.models.resource_type_dto import ResourceTypeDto
from perceptic_core_client.models.run_status_dto import RunStatusDto
from perceptic_core_client.models.s3_connection_settings_api_dto import S3ConnectionSettingsApiDto
from perceptic_core_client.models.s3_file_system_root_metadata_api_dto import S3FileSystemRootMetadataApiDto
from perceptic_core_client.models.schedule_execution_dto import ScheduleExecutionDto
from perceptic_core_client.models.schedule_trigger import ScheduleTrigger
from perceptic_core_client.models.schema_location import SchemaLocation
from perceptic_core_client.models.start_execution_response import StartExecutionResponse
from perceptic_core_client.models.tag_info import TagInfo
from perceptic_core_client.models.update_indexing_schedule_request import UpdateIndexingScheduleRequest
from perceptic_core_client.models.update_indexing_schedule_response import UpdateIndexingScheduleResponse
from perceptic_core_client.models.update_tag_request import UpdateTagRequest
from perceptic_core_client.models.update_tag_response import UpdateTagResponse
from perceptic_core_client.models.upload_file_to_managed_file_system_response import UploadFileToManagedFileSystemResponse
from perceptic_core_client.models.upload_resource_response_v2 import UploadResourceResponseV2
from perceptic_core_client.models.user_info_response import UserInfoResponse
from perceptic_core_client.models.user_input_event import UserInputEvent
from perceptic_core_client.models.user_request_for_input_event import UserRequestForInputEvent
from perceptic_core_client.models.web_page_citation_metadata_api_dto import WebPageCitationMetadataApiDto
from perceptic_core_client.models.worker_event import WorkerEvent
from perceptic_core_client.models.worker_event_v2 import WorkerEventV2
from perceptic_core_client.models.worker_metadata_dto import WorkerMetadataDto
from perceptic_core_client.models.worker_run_event_rating_secondary_id import WorkerRunEventRatingSecondaryId
from perceptic_core_client.models.worker_v2_next_page_token import WorkerV2NextPageToken
from perceptic_core_client.models.workflow_status_response import WorkflowStatusResponse




import argparse
import subprocess
import sys
import os
import shutil
from pathlib import Path

# --- Configuration ---
PACKAGE_NAME = "perceptic_core_client"
PROJECT_ROOT = Path(__file__).parent.parent.resolve()
OUTPUT_DIR = PROJECT_ROOT / "src"
VERSION_FILE = PROJECT_ROOT / "VERSION"
# ---

def check_java():
    """Checks if Java is installed and accessible."""
    try:
        subprocess.run(["java", "-version"], check=True, capture_output=True)
        print("Java installation found.")
        return True
    except (subprocess.CalledProcessError, FileNotFoundError):
        print("Error: Java Runtime Environment (JRE) not found.", file=sys.stderr)
        print("openapi-generator-cli requires Java to run.", file=sys.stderr)
        print("Please install Java and ensure it's in your PATH.", file=sys.stderr)
        return False

def check_openapi_generator():
    """Checks if openapi-generator-cli is installed and accessible."""
    try:
        subprocess.run(["openapi-generator-cli", "list"], check=True, capture_output=True)
        print("openapi-generator-cli found.")
        return True
    except (subprocess.CalledProcessError, FileNotFoundError):
        print("Error: openapi-generator-cli not found.", file=sys.stderr)
        print("Please install it, e.g., using 'npm install @openapitools/openapi-generator-cli -g' or ensure it's in your PATH.", file=sys.stderr)
        return False

def run_generator(spec_path: Path, output_dir: Path, package_name: str):
    """Runs the openapi-generator-cli command."""
    if not spec_path.is_file():
        print(f"Error: OpenAPI spec file not found at: {spec_path}", file=sys.stderr)
        return False

    # Ensure output directory exists and is empty
    if output_dir.exists():
         print(f"Cleaning existing output directory: {output_dir}")
         if str(output_dir).startswith(str(PROJECT_ROOT / "src")): # Basic safety check
             shutil.rmtree(output_dir)
         else:
             print(f"Error: Output directory {output_dir} seems unsafe to remove.", file=sys.stderr)
             return False
    output_dir.mkdir(parents=True)

    additional_props = f"projectName={package_name},useOneOfDiscriminatorLookup=true,generateSourceCodeOnly=true,packageName={package_name}"

    command = [
        "openapi-generator-cli", "generate",
        "-g", "python",
        "-i", str(spec_path),
        "-o", str(output_dir),
        # "--package-name", package_name, # Handled by additional props
        "--skip-validate-spec",
        "--additional-properties", additional_props
    ]

    print(f"Running generator command: {' '.join(command)}")
    try:
        process = subprocess.run(command, check=True, capture_output=True, text=True)
        print("Generator output:")
        print(process.stdout)
        if process.stderr:
             print("Generator errors/warnings:", file=sys.stderr)
             print(process.stderr, file=sys.stderr)
        print("Client generation successful.")
        return True
    except subprocess.CalledProcessError as e:
        print(f"Error running openapi-generator-cli: {e}", file=sys.stderr)
        print("Command output:", file=sys.stderr)
        print(e.stdout, file=sys.stderr)
        print(e.stderr, file=sys.stderr)
        return False
    except FileNotFoundError:
         print("Error: 'openapi-generator-cli' command not found. Is it installed and in PATH?", file=sys.stderr)
         return False
    except Exception as e: # Catch other potential errors like JSON parsing
         print(f"An unexpected error occurred during generation: {e}", file=sys.stderr)
         return False

def write_version_file(version: str, version_file_path: Path):
    """Writes the version to the VERSION file."""
    print(f"Writing version '{version}' to {version_file_path}")
    try:
        version_file_path.write_text(version.strip() + "\n", encoding='utf-8')
        return True
    except IOError as e:
        print(f"Error writing VERSION file: {e}", file=sys.stderr)
        return False

def main():
    parser = argparse.ArgumentParser(description="Generate Python client from a local Perceptic Core OpenAPI spec file.")
    parser.add_argument(
        "--spec-path",
        type=Path,
        required=True,
        help="Path to the local OpenAPI specification file"
    )
    parser.add_argument(
        "--version",
        type=str,
        required=True,
        help="The version string to assign to the package (e.g., 0.5.0)"
    )
    args = parser.parse_args()
    spec_path = args.spec_path.resolve() # Get absolute path
    version = args.version

    print(f"--- Starting client generation from spec: {spec_path} for version: {version} ---")

    # --- Pre-checks ---
    if not check_java() or not check_openapi_generator():
        sys.exit(1)

    # --- Generate Client ---
    if not run_generator(spec_path, OUTPUT_DIR, PACKAGE_NAME):
         print("Client generation failed.", file=sys.stderr)
         sys.exit(1)

    # --- Write Version ---
    if not write_version_file(version, VERSION_FILE):
         sys.exit(1)

    print(f"--- Client generation completed successfully for version: {version} ---")
    print(f"Generated client code is in: {OUTPUT_DIR}")
    print(f"Version file created at: {VERSION_FILE}")

if __name__ == "__main__":
    main()



# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from perceptic_core_client.models.image_detection_box_api_dto import ImageDetectionBoxApiDto
from typing import Optional, Set
from typing_extensions import Self

class BiotechAnalysisApiDto(BaseModel):
    """
    BiotechAnalysisApiDto
    """ # noqa: E501
    raw_analysis: Optional[StrictStr] = Field(default=None, alias="rawAnalysis")
    compound_data_present: Optional[StrictBool] = Field(default=None, alias="compoundDataPresent")
    compounds: Optional[List[StrictStr]] = None
    development_stage: Optional[StrictStr] = Field(default=None, alias="developmentStage")
    therapeutic_area: Optional[StrictStr] = Field(default=None, alias="therapeuticArea")
    key_findings: Optional[List[StrictStr]] = Field(default=None, alias="keyFindings")
    risks: Optional[List[StrictStr]] = None
    market_potential: Optional[StrictStr] = Field(default=None, alias="marketPotential")
    confidence: Optional[Union[StrictFloat, StrictInt]] = None
    reasoning: Optional[StrictStr] = None
    bounding_boxes: Optional[List[ImageDetectionBoxApiDto]] = Field(default=None, alias="boundingBoxes")
    page_index: Optional[StrictInt] = Field(default=None, alias="pageIndex")
    character_count: Optional[StrictInt] = Field(default=None, alias="characterCount")
    __properties: ClassVar[List[str]] = ["rawAnalysis", "compoundDataPresent", "compounds", "developmentStage", "therapeuticArea", "keyFindings", "risks", "marketPotential", "confidence", "reasoning", "boundingBoxes", "pageIndex", "characterCount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BiotechAnalysisApiDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in bounding_boxes (list)
        _items = []
        if self.bounding_boxes:
            for _item_bounding_boxes in self.bounding_boxes:
                if _item_bounding_boxes:
                    _items.append(_item_bounding_boxes.to_dict())
            _dict['boundingBoxes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BiotechAnalysisApiDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "rawAnalysis": obj.get("rawAnalysis"),
            "compoundDataPresent": obj.get("compoundDataPresent"),
            "compounds": obj.get("compounds"),
            "developmentStage": obj.get("developmentStage"),
            "therapeuticArea": obj.get("therapeuticArea"),
            "keyFindings": obj.get("keyFindings"),
            "risks": obj.get("risks"),
            "marketPotential": obj.get("marketPotential"),
            "confidence": obj.get("confidence"),
            "reasoning": obj.get("reasoning"),
            "boundingBoxes": [ImageDetectionBoxApiDto.from_dict(_item) for _item in obj["boundingBoxes"]] if obj.get("boundingBoxes") is not None else None,
            "pageIndex": obj.get("pageIndex"),
            "characterCount": obj.get("characterCount")
        })
        return _obj





# flake8: noqa

# import apis into api package
from perceptic_core_client.api.citations_resource_api import CitationsResourceApi
from perceptic_core_client.api.connection_resource_api import ConnectionResourceApi
from perceptic_core_client.api.file_system_contents_resource_api import FileSystemContentsResourceApi
from perceptic_core_client.api.file_system_resource_api import FileSystemResourceApi
from perceptic_core_client.api.indexer_resource_api import IndexerResourceApi
from perceptic_core_client.api.indexing_schedule_resource_api import IndexingScheduleResourceApi
from perceptic_core_client.api.indexing_task_resource_api import IndexingTaskResourceApi
from perceptic_core_client.api.tag_resource_api import TagResourceApi
from perceptic_core_client.api.uri_resource_api import UriResourceApi
from perceptic_core_client.api.user_resource_api import UserResourceApi
from perceptic_core_client.api.worker_resource_api import WorkerResourceApi
from perceptic_core_client.api.workflow_resource_v3_api import WorkflowResourceV3Api




# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.post_run_event_rating_response import PostRunEventRatingResponse

class TestPostRunEventRatingResponse(unittest.TestCase):
    """PostRunEventRatingResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PostRunEventRatingResponse:
        """Test PostRunEventRatingResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PostRunEventRatingResponse`
        """
        model = PostRunEventRatingResponse()
        if include_optional:
            return PostRunEventRatingResponse(
                rating = perceptic_core_client.models.rating_dto_worker_run_event_rating_secondary_id.RatingDtoWorkerRunEventRatingSecondaryId(
                    id = '62ECB020-8429-30cc-01FF-CCfeEe150AC3', 
                    grade = 1.337, 
                    written_feedback = '', 
                    secondary_id = perceptic_core_client.models.worker_run_event_rating_secondary_id.WorkerRunEventRatingSecondaryId(
                        run_rid = '', 
                        sequence = 56, ), )
            )
        else:
            return PostRunEventRatingResponse(
        )
        """

    def testPostRunEventRatingResponse(self):
        """Test PostRunEventRatingResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from uuid import UUID
from perceptic_core_client.models.worker_run_event_rating_secondary_id import WorkerRunEventRatingSecondaryId
from typing import Optional, Set
from typing_extensions import Self

class RatingDtoWorkerRunEventRatingSecondaryId(BaseModel):
    """
    RatingDtoWorkerRunEventRatingSecondaryId
    """ # noqa: E501
    id: Optional[UUID] = None
    grade: Optional[Union[StrictFloat, StrictInt]] = None
    written_feedback: Optional[StrictStr] = Field(default=None, alias="writtenFeedback")
    secondary_id: Optional[WorkerRunEventRatingSecondaryId] = Field(default=None, alias="secondaryId")
    __properties: ClassVar[List[str]] = ["id", "grade", "writtenFeedback", "secondaryId"]

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}", value):
            raise ValueError(r"must validate the regular expression /[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RatingDtoWorkerRunEventRatingSecondaryId from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of secondary_id
        if self.secondary_id:
            _dict['secondaryId'] = self.secondary_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RatingDtoWorkerRunEventRatingSecondaryId from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "grade": obj.get("grade"),
            "writtenFeedback": obj.get("writtenFeedback"),
            "secondaryId": WorkerRunEventRatingSecondaryId.from_dict(obj["secondaryId"]) if obj.get("secondaryId") is not None else None
        })
        return _obj





# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.workflow_resource_v3_api import WorkflowResourceV3Api


class TestWorkflowResourceV3Api(unittest.TestCase):
    """WorkflowResourceV3Api unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkflowResourceV3Api()

    def tearDown(self) -> None:
        pass

    def test_api_v3_workflows_workflow_id_runs_post(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_post

        Start Workflow Run
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_cancel_post(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_cancel_post

        Interrupt
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_checkpoints_checkpoint_name_post(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_checkpoints_checkpoint_name_post

        Invoke Checkpoint
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_events_get(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_events_get

        Get Run Events
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_get(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_get

        Get Workflow Status
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_stream_get(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_stream_get

        Stream Run
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_user_input_post(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_user_input_post

        Submit User Input
        """
        pass


if __name__ == '__main__':
    unittest.main()
